@@ -6,6 +6,7 @@ from .chat_view import ChatView
 from .copy_button import CopyButton
 from .custom_widgets import CustomTextArea
 from .input_area import InputArea, SimpleSpinnerWidget, SubmitCancelButton
+from .right_sidebar import RightSidebar
 from .sidebar import Sidebar
 from .status_bar import StatusBar
 
@@ -18,4 +19,5 @@ __all__ = [
     "SimpleSpinnerWidget",
     "SubmitCancelButton",
     "Sidebar",
+    "RightSidebar",
 ]
